//
// game.cpp
// 
// Simple illustration of a player-controlled camera.
//

#define VERSION 1.6

// Engine includes
#include "DisplayManager.h"
#include "GameManager.h"
#include "LogManager.h"
#include "WorldManager.h"

// Game includes
#include "Camera.h"
#include "Rock.h"

int main(int argc, char *argv[]) {

  // Start up Game Manager.
  if (GM.startUp())  {
    LM.writeLog("Error starting game manager!");
    GM.shutDown();
    return 0;
  }

  // Set world boundary twice as big as the screen with no view slack.
  df::Box boundary = WM.getBoundary();
  df::Vector corner(0,0);
  df::Box new_boundary(corner, 
		       boundary.getHorizontal()*2,
		       boundary.getVertical()*2);
  WM.setBoundary(new_boundary);
  WM.setViewSlack(df::Vector(0,0));

  // Splash screen
  df::splash();

  // Create Camera object to move the view.
  new Camera;

  // Create some rocks for decoration.
  for (int i=0; i<100; i++)
    new Rock;

  // Run game (this blocks until the game loop is over).
  GM.run();

  // Shut everything down.
  GM.shutDown();
}
